#JES- Jython Environment for Students
#Copyright (C) 2002  Jason Ergle, Claire Bailey, David Raines, Joshua Sklare
#See JESCopyright.txt for full licensing information

import JESConstants
import JESEditorDocument
import java.awt as awt
import javax.swing as swing

class JESEditor(swing.JTextPane,
                swing.event.DocumentListener,
                swing.event.CaretListener):
################################################################################
# Function name: __init__
# Parameters:
#     -gui: JESUI object that this object is associated with
# Return:
#     An instance of the JESEditor class.
# Description:
#     Creates an instance of the JESEditor class.
################################################################################
    def __init__(self, gui):
        self.gui     = gui
        self.program = gui.program
        self.setDocument(JESEditorDocument.JESEditorDocument(self))
        self.addCaretListener(self)
        self.modified = 0


################################################################################
# Function name: showErrorLine
# Parameters:
#      -lineNumber
# Description:
#     When this function is called, the specified line will be highlighted so
#     that the user can tell which line contains an error.
################################################################################
    def showErrorLine(self, lineNumber):
        self.document.showErrorLine(lineNumber)

################################################################################
# Function name: undo
# Description:
#     This function can be called to undo the last text modification that was
#     performed.
################################################################################
    def undo(self):
        self.document.undo()

################################################################################
# Function name: getScrollableTracksViewportWidth
# Description:
#     Overrides base getScrollableTracksViewportWidth function to disable
#     word-wrapping.
################################################################################
    def getScrollableTracksViewportWidth(self):
        parent = self.getParent()
        ui     = self.getUI()
        return ui.getPreferredSize(self).width <= parent.getSize().width

################################################################################
# Function name: caretUpdate
# Parameters:
#      -e: event object containing infomation about the caret event
# Description:
#     Catches the caretUpdate event for the JESEditorClass.  It then updates
#     the gui status bar with the current row and column.
################################################################################
    def caretUpdate(self, e):
        offset = self.getCaretPosition()
        defaultElement = self.document.getDefaultRootElement()
        elementIndex = defaultElement.getElementIndex(offset)
        row = offset-defaultElement.getElement(elementIndex).getStartOffset()+1
        col = elementIndex + 1
        self.gui.UpdateRowCol(row, col)

################################################################################
# Function name: setText
# Parameters:
#      -text: text that is being put into the editor
# Description:
#     Overrides the default setText function of the JTextPane.  It resets the
#     modified flag to false, so that the user is not prompted to save on load
#     (unless they make a modification to the file).
################################################################################
    def setText(self, text):
        self.modified = 0
        self.gui.loadButton.enabled = 0
        self.document.undoEvents = []
        swing.JTextPane.setText(self, text)
        self.setCaretPosition(0)
